@@ -13,11 +13,10 @@ use Blosxom::Header qw(
 
 my $header = Blosxom::Header->new;
 my $tied_hash = $header->as_hashref;
-my $adapter = tied %{ $header };
 
 # STORE
 cmpthese(300000, {
-    STORE     => sub { $adapter->STORE( Foo => 'bar' ) },
+    STORE     => sub { $header->STORE( Foo => 'bar' )  },
     tied_hash => sub { $tied_hash->{Foo} = 'bar'       },
     overload  => sub { $header->{Foo} = 'bar'          },
     method    => sub { $header->set( Foo => 'bar' )    },
@@ -26,16 +25,16 @@ cmpthese(300000, {
 
 # FETCH
 cmpthese(300000, {
-    FETCH     => sub { my $value = $adapter->FETCH( 'Foo' ) },
-    tied_hash => sub { my $value = $tied_hash->{Foo}        },
-    overload  => sub { my $value = $header->{Foo}           },
-    method    => sub { my $value = $header->get( 'Foo' )    },
-    function  => sub { my $value = header_get( 'Foo' )      },
+    FETCH     => sub { my $value = $header->FETCH( 'Foo' ) },
+    tied_hash => sub { my $value = $tied_hash->{Foo}       },
+    overload  => sub { my $value = $header->{Foo}          },
+    method    => sub { my $value = $header->get( 'Foo' )   },
+    function  => sub { my $value = header_get( 'Foo' )     },
 });
 
 # EXISTS
 cmpthese(300000, {
-    EXISTS    => sub { my $bool = $adapter->EXISTS( 'Foo' ) },
+    EXISTS    => sub { my $bool = $header->EXISTS( 'Foo' )  },
     tied_hash => sub { my $bool = exists $tied_hash->{Foo}  },
     overload  => sub { my $bool = exists $header->{Foo}     },
     method    => sub { my $bool = $header->exists( 'Foo' )  },
@@ -46,7 +45,7 @@ cmpthese(300000, {
 cmpthese(300000, {
     DELETE => sub {
         $blosxom::header->{-foo} = 'bar';
-        my $deleted = $adapter->DELETE( 'Foo' )
+        my $deleted = $header->DELETE( 'Foo' )
     },
     tied_hash => sub {
         $blosxom::header->{-foo} = 'bar';
@@ -66,6 +65,14 @@ cmpthese(300000, {
     },
 });
 
+# CLEAR
+cmpthese(300000, {
+    CLEAR     => sub { $header->CLEAR       },
+    tied_hash => sub { %{ $tied_hash } = () },
+    overload  => sub { %{ $header } = ()    },
+    method    => sub { $header->clear       },
+});
+
 $header->set(
     Foo => 'bar',
     Bar => 'baz',
